@@ -530,7 +530,7 @@ parse_url_char(enum state s, const char ch, int strict_flag)
 #if __cplusplus
       [[fallthrough]];
 #else /* __cplusplus */
-    /* FALLTHROUGH */
+    __attribute__((fallthrough));
 #endif /* __cplusplus */
     case s_req_server_start:
     case s_req_server:
@@ -679,11 +679,11 @@ size_t http_parser_execute_options (http_parser *parser,
   /* technically we could combine all of these (except for url_mark) into one
      variable, saving stack space, but it seems more clear to have them
      separated. */
-  const char *header_field_mark = 0;
-  const char *header_value_mark = 0;
-  const char *url_mark = 0;
-  const char *reason_mark = 0;
-  const char *body_mark = 0;
+  const char *header_field_mark = nullptr;
+  const char *header_value_mark = nullptr;
+  const char *url_mark = nullptr;
+  const char *reason_mark = nullptr;
+  const char *body_mark = nullptr;
 
   if (state == s_header_field)
     header_field_mark = data;
@@ -2252,7 +2252,7 @@ http_parse_host_char(enum http_host_state s, const char ch) {
 #if __cplusplus
       [[fallthrough]];
 #else /* __cplusplus */
-    /* FALLTHROUGH */
+    __attribute__((fallthrough));
 #endif /* __cplusplus */
     case s_http_host_v6_end:
       if (ch == ':') {
@@ -2269,7 +2269,7 @@ http_parse_host_char(enum http_host_state s, const char ch) {
 #if __cplusplus
       [[fallthrough]];
 #else /* __cplusplus */
-    /* FALLTHROUGH */
+    __attribute__((fallthrough));
 #endif /* __cplusplus */
     case s_http_host_v6_start:
       if (IS_HEX(ch) || ch == ':' || ch == '.') {
@@ -2412,7 +2412,7 @@ http_parser_parse_url_options(const char *buf, size_t buflen, int is_connect,
 #if __cplusplus
         [[fallthrough]];
 #else /* __cplusplus */
-      /* FALLTHROUGH */
+      __attribute__((fallthrough));
 #endif /* __cplusplus */
       case s_req_server:
         uf = UF_HOST;
