@@ -58,7 +58,9 @@ DEFINE_bool(sequential,
             false,
             "Whether to make requests sequentially or in parallel when "
             "multiple paths are provided");
-DEFINE_uint32(gap_ms, 0, "Time between consecutive requests in milliseconds");
+DEFINE_string(gap_ms,
+              "0",
+              "Comma separated list of gaps in ms between requests");
 DEFINE_string(congestion, "cubic", "newreno/cubic/bbr/none");
 DEFINE_int32(conn_flow_control, 1024 * 1024 * 10, "Connection flow control");
 DEFINE_int32(stream_flow_control, 256 * 1024, "Stream flow control");
@@ -120,6 +122,21 @@ DEFINE_uint32(
     max_ack_receive_timestamps_to_send,
     quic::kMaxReceivedPktsTimestampsStored,
     "Controls how many packet receieve timestamps the peer should send");
+DEFINE_bool(initiate_key_updates,
+            false,
+            "Whether to initiate periodic key updates");
+DEFINE_uint32(key_update_interval,
+              quic::kDefaultKeyUpdatePacketCountInterval,
+              "Number of packets to be sent before initiating a key update (if "
+              "initiate_key_updates is true)");
+DEFINE_bool(
+    writer_backpressure,
+    false,
+    "Enable backpressure in the batch writer. Only for non-batched writer");
+DEFINE_bool(use_l4s_ecn, false, "Whether to use L4S for ECN marking");
+DEFINE_bool(read_ecn,
+            false,
+            "Whether to read and echo ecn marking from ingress packets");
 
 namespace quic::samples {
 
@@ -227,6 +244,8 @@ void initializeTransportSettings(HQToolParams& hqUberParams) {
   hqParams.transportSettings.batchingMode =
       quic::getQuicBatchingMode(FLAGS_quic_batching_mode);
   hqParams.transportSettings.maxBatchSize = FLAGS_quic_batch_size;
+  hqParams.transportSettings.enableWriterBackpressure =
+      FLAGS_writer_backpressure;
   if (hqUberParams.mode == HQMode::CLIENT) {
     // There is no good reason to keep the socket around for a drain period for
     // a commandline client
@@ -270,6 +289,25 @@ void initializeTransportSettings(HQToolParams& hqUberParams) {
          .receiveTimestampsExponent = kDefaultReceiveTimestampsExponent});
   }
   hqParams.transportSettings.datagramConfig.enabled = true;
+
+  hqParams.transportSettings.initiateKeyUpdate = FLAGS_initiate_key_updates;
+  hqParams.transportSettings.keyUpdatePacketCountInterval =
+      FLAGS_key_update_interval;
+
+  if (FLAGS_use_l4s_ecn) {
+    hqParams.transportSettings.enableEcnOnEgress = true;
+    hqParams.transportSettings.useL4sEcn = true;
+    hqParams.transportSettings.minBurstPackets = 1;
+    hqParams.transportSettings.experimentalPacer = true;
+    hqParams.transportSettings.ccaConfig.onlyGrowCwndWhenLimited = true;
+    hqParams.transportSettings.ccaConfig.leaveHeadroomForCwndLimited = true;
+  }
+
+  if (FLAGS_read_ecn) {
+    hqParams.transportSettings.readEcnOnIngress = FLAGS_read_ecn;
+    hqParams.transportSettings.shouldRecvBatch = false;
+  }
+
 } // initializeTransportSettings
 
 void initializeHttpServerSettings(HQToolServerParams& hqParams) {
@@ -307,7 +345,7 @@ void initializeHttpClientSettings(HQToolClientParams& hqParams) {
   hqParams.logResponse = FLAGS_log_response;
   hqParams.logResponseHeaders = FLAGS_log_response_headers;
   hqParams.sendRequestsSequentially = FLAGS_sequential;
-  hqParams.gapBetweenRequests = std::chrono::milliseconds(FLAGS_gap_ms);
+  folly::split(',', FLAGS_gap_ms, hqParams.requestGaps);
 
   hqParams.earlyData = FLAGS_early_data;
   hqParams.migrateClient = FLAGS_migrate_client;
