@@ -47,11 +47,13 @@ struct HQBaseParams {
       quic::QuicVersion::MVFST,
       quic::QuicVersion::MVFST_EXPERIMENTAL,
       quic::QuicVersion::QUIC_V1,
-      quic::QuicVersion::QUIC_V1_ALIAS};
+      quic::QuicVersion::QUIC_V1_ALIAS,
+      quic::QuicVersion::QUIC_V1_ALIAS2};
   std::vector<std::string> supportedAlpns{proxygen::kH3,
                                           proxygen::kHQ,
                                           proxygen::kH3FBCurrentDraft,
                                           proxygen::kH3AliasV1,
+                                          proxygen::kH3AliasV2,
                                           proxygen::kH3CurrentDraft,
                                           proxygen::kHQCurrentDraft};
   quic::TransportSettings transportSettings;
