@@ -56,8 +56,6 @@ struct HTTPPriority {
         incremental(incrementalIn),
         orderId(orderIdIn) {
   }
-
-  virtual ~HTTPPriority() = default;
 };
 
 inline bool operator==(const HTTPPriority& a, const HTTPPriority& b) {
@@ -653,7 +651,8 @@ class HTTPMessage {
    * It is expected that during request processing, stripPerHopHeaders() will
    * be called before the message is proxied to the other connection.
    */
-  void stripPerHopHeaders(bool stripPriority = false);
+  void stripPerHopHeaders(bool stripPriority = false,
+                          const HTTPHeaders* customHeaders = nullptr);
 
   const HTTPHeaders& getStrippedPerHopHeaders() const {
     CHECK(strippedPerHopHeaders_) << "call stripPerHopHeaders first";
@@ -781,7 +780,7 @@ class HTTPMessage {
     return h2Pri_;
   }
 
-  void setHTTP2Priority(HTTP2Priority h2Pri) {
+  void setHTTP2Priority(const HTTP2Priority& h2Pri) {
     h2Pri_ = h2Pri;
   }
 
