@@ -38,14 +38,15 @@ namespace proxygen {
       x(http_body_parsing_error), x(http_eom_before_headers),                  \
       x(http_headers_parsing_error), x(http_partial_reliability_disabled),     \
       x(http_trailers_before_headers), x(no_server_available),                 \
-      x(proxy_adaptive_rate_limit), x(sc_channel_invalid_argument),            \
-      x(sc_channel_unknown_error), x(sc_eom_before_headers),                   \
-      x(sc_upstream_timeout), x(sc_runtime_exception),                         \
-      x(sc_content_integrity_error), x(live_head_error),                       \
-      x(redirect_connect_error), x(redirect_limit_exceeded),                   \
-      x(redirect_pool_error), x(redirect_request_too_large),                   \
-      x(server_connection_error), x(server_timeout), x(server_write_error),    \
-      x(telephoto_error), x(wasm_invocation_error), x(transcode_server_error), \
+      x(proxy_adaptive_rate_limit), x(request_rate_limited),                   \
+      x(sc_channel_invalid_argument), x(sc_channel_unknown_error),             \
+      x(sc_eom_before_headers), x(sc_upstream_timeout),                        \
+      x(sc_runtime_exception), x(sc_content_integrity_error),                  \
+      x(live_head_error), x(redirect_connect_error),                           \
+      x(redirect_limit_exceeded), x(redirect_pool_error),                      \
+      x(redirect_request_too_large), x(server_connection_error),               \
+      x(server_timeout), x(server_write_error), x(telephoto_error),            \
+      x(wasm_invocation_error), x(transcode_server_error),                     \
       x(fbvp_channel_error), x(server_internal_error), x(invalid_pool),        \
       x(qoe_error), x(sc_downstream_error), x(content_integrity),              \
       x(bad_request),                                                          \
@@ -54,7 +55,7 @@ namespace proxygen {
       x(manifest_missing_representation), x(manifest_with_0_bitrate),          \
       x(manifest_with_no_tracks), x(manifest_with_wrong_track),                \
       x(cache_lease_queue_hard_timeout), x(cache_purge), x(cache_error),       \
-      x(proxy_cache_fill_shed), x(ENUM_COUNT)
+      x(proxy_cache_fill_shed), x(ENUM_COUNT), x(takedown_direct_response)
 
 #define STATUS_TYPE_ENUM(statusType) statusType
 
