@@ -17,6 +17,19 @@ namespace proxygen { namespace hq {
 class HQMultiCodec : public HQControlCodec {
 
  public:
+  class Factory {
+   public:
+    static std::unique_ptr<HQMultiCodec> getCodec(
+        TransportDirection direction,
+        bool useStrictValidation,
+        const HeaderIndexingStrategy* strat) {
+      auto codec = std::make_unique<HQMultiCodec>(direction);
+      codec->setStrictValidation(useStrictValidation);
+      codec->getQPACKCodec().setHeaderIndexingStrategy(strat);
+      return codec;
+    }
+  };
+
   explicit HQMultiCodec(TransportDirection direction)
       : HQControlCodec(HTTPCodec::MaxStreamID,
                        direction,
@@ -49,6 +62,10 @@ class HQMultiCodec : public HQControlCodec {
     return true;
   }
 
+  void setStrictValidation(bool strict) {
+    strictValidation_ = strict;
+  }
+
   bool isStreamIngressEgressAllowed(StreamID streamId) const {
     CHECK(transportDirection_ == TransportDirection::DOWNSTREAM);
     return streamId < egressGoawayAck_;
@@ -73,6 +90,7 @@ class HQMultiCodec : public HQControlCodec {
                                                         settings_));
     auto& codec = res.first->second;
     codec->setCallback(callback_);
+    codec->setStrictValidation(strictValidation_);
     return *codec;
   }
 
@@ -267,6 +285,7 @@ class HQMultiCodec : public HQControlCodec {
       folly::IOBufQueue::cacheChainLength()};
   std::function<uint64_t()> qpackEncoderMaxDataFn_;
   uint64_t nextPushID_{0};
+  bool strictValidation_{true};
 };
 
 }} // namespace proxygen::hq
