@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  * All rights reserved.
  *
  * This source code is licensed under the BSD-style license found in the
@@ -34,7 +34,7 @@ const HPACKHeader& QPACKContext::getHeader(bool isStatic,
 
 void QPACKContext::seedHeaderTable(std::vector<HPACKHeader>& headers) {
   for (auto& header : headers) {
-    table_.add(std::move(header));
+    CHECK(table_.add(std::move(header)));
   }
 }
 
