@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Facebook, Inc. and its affiliates.
+ * Copyright (c) Meta Platforms, Inc. and affiliates.
  * All rights reserved.
  *
  * This source code is licensed under the BSD-style license found in the
@@ -7,6 +7,7 @@
  */
 
 #include <proxygen/lib/http/codec/compress/QPACKDecoder.h>
+
 #include <proxygen/lib/http/codec/compress/HPACKEncodeBuffer.h>
 
 using folly::io::Cursor;
@@ -30,7 +31,7 @@ void QPACKDecoder::decodeStreaming(uint64_t streamID,
     VLOG(5) << "requiredInsertCount=" << requiredInsertCount
             << " > insertCount=" << table_.getInsertCount() << ", queuing";
     if (queue_.size() >= maxBlocking_) {
-      VLOG(2) << "QPACK queue is full size=" << queue_.size()
+      VLOG(2) << "QPACK queue full size=" << queue_.size()
               << " maxBlocking_=" << maxBlocking_;
       err_ = HPACK::DecodeError::TOO_MANY_BLOCKING;
       completeDecode(HeaderCodec::Type::QPACK, streamingCb, 0, 0, 0, false);
@@ -100,7 +101,7 @@ uint32_t QPACKDecoder::decodePrefix(HPACKDecodeBuffer& dbuf) {
   if (neg) {
     // delta must be smaller than RIC
     if (delta >= requiredInsertCount) {
-      LOG(ERROR) << "Invalid delta=" << delta
+      LOG(ERROR) << "Received invalid delta=" << delta
                  << " requiredInsertCount=" << requiredInsertCount;
       err_ = HPACK::DecodeError::INVALID_INDEX;
       return 0;
@@ -135,7 +136,7 @@ void QPACKDecoder::decodeStreamingImpl(uint32_t requiredInsertCount,
   while (!hasError() && !dbuf.empty()) {
     emittedSize += decodeHeaderQ(dbuf, streamingCb);
     if (emittedSize > maxUncompressed_) {
-      LOG(ERROR) << "exceeded uncompressed size limit of " << maxUncompressed_
+      LOG(ERROR) << "Exceeded uncompressed size limit of " << maxUncompressed_
                  << " bytes";
       err_ = HPACK::DecodeError::HEADERS_TOO_LARGE;
       break;
@@ -219,6 +220,19 @@ HPACK::DecodeError QPACKDecoder::decodeEncoderStream(
   }
 }
 
+HPACK::DecodeError QPACKDecoder::encoderStreamEnd() {
+  if (!ingress_.empty()) {
+    err_ = HPACK::DecodeError::BUFFER_UNDERFLOW;
+  }
+  if (!queue_.empty()) {
+    if (err_ != HPACK::DecodeError::NONE) {
+      err_ = HPACK::DecodeError::ENCODER_STREAM_CLOSED;
+    }
+    errorQueue();
+  }
+  return err_;
+}
+
 void QPACKDecoder::decodeEncoderStreamInstruction(HPACKDecodeBuffer& dbuf) {
   uint8_t byte = dbuf.peek();
   partial_.consumed = dbuf.consumedBytes();
@@ -284,7 +298,7 @@ uint32_t QPACKDecoder::decodeLiteralHeaderQ(
       nameIndex++;
       // validate the index
       if (!isValid(isStaticName, nameIndex, aboveBase)) {
-        LOG(ERROR) << "received invalid index: " << nameIndex;
+        LOG(ERROR) << "Received invalid index=" << nameIndex;
         err_ = HPACK::DecodeError::INVALID_INDEX;
         return 0;
       }
@@ -401,6 +415,7 @@ std::unique_ptr<folly::IOBuf> QPACKDecoder::encodeHeaderAck(
 std::unique_ptr<folly::IOBuf> QPACKDecoder::encodeCancelStream(
     uint64_t streamId) {
   // Remove this stream from the queue
+  VLOG(6) << "encodeCancelStream id=" << streamId;
   auto it = queue_.begin();
   while (it != queue_.end()) {
     if (it->second.streamID == streamId) {
@@ -448,7 +463,7 @@ bool QPACKDecoder::decodeBlock(uint32_t requiredInsertCount,
     folly::DestructorCheck::Safety safety(*this);
     decodeStreamingImpl(
         requiredInsertCount, pending.consumed, dbuf, pending.cb);
-    // The callback way destroy this, if so stop queue processing
+    // The callback may destroy this, if so stop queue processing
     if (safety.destroyed()) {
       return true;
     }
@@ -470,4 +485,15 @@ void QPACKDecoder::drainQueue() {
   }
 }
 
+void QPACKDecoder::errorQueue() {
+  // The callback may destroy this, if so stop queue processing
+  folly::DestructorCheck::Safety safety(*this);
+  while (!safety.destroyed() && !queue_.empty()) {
+    auto it = queue_.begin();
+    PendingBlock block = std::move(it->second);
+    queue_.erase(it);
+    block.cb->onDecodeError(HPACK::DecodeError::ENCODER_STREAM_CLOSED);
+  }
+}
+
 } // namespace proxygen
