@@ -109,7 +109,9 @@ HTTPTransaction::HTTPTransaction(
       isDelegated_(false),
       idleTimeout_(defaultIdleTimeout),
       timer_(timer),
-      setIngressTimeoutAfterEom_(setIngressTimeoutAfterEom) {
+      setIngressTimeoutAfterEom_(setIngressTimeoutAfterEom),
+      txnObserverAccessor_(this),
+      txnObserverContainer_(&txnObserverAccessor_) {
   if (assocStreamId_) {
     if (isUpstream()) {
       egressState_ = HTTPTransactionEgressSM::State::SendingDone;
@@ -668,6 +670,22 @@ void HTTPTransaction::abortAndDeliverError(ErrorCode codecError,
 }
 
 void HTTPTransaction::onError(const HTTPException& error) {
+  /**
+   * Defer ingress RST_STREAM w/ NO_ERROR if ingress EOM is queued. Downstream
+   * may send full response prior to upstream sending entire request.
+   */
+  if (isUpstream() && error.hasCodecStatusCode() &&
+      error.getCodecStatusCode() == ErrorCode::NO_ERROR &&
+      isIngressEOMQueued()) {
+    checkCreateDeferredIngress();
+    deferredIngress_->emplace(id_, std::make_unique<HTTPException>(error));
+    return;
+  }
+
+  processIngressError(error);
+}
+
+void HTTPTransaction::processIngressError(const HTTPException& error) {
   DestructorGuard g(this);
 
   const bool wasAborted = aborted_; // see comment below
@@ -766,7 +784,16 @@ void HTTPTransaction::onIngressTimeout() {
     if (windowUpdateTimeout) {
       HTTPException ex(
           HTTPException::Direction::INGRESS_AND_EGRESS,
-          folly::to<std::string>("ingress timeout, streamID=", id_));
+          folly::to<std::string>(
+              "ingress timeout, streamID=",
+              id_,
+              ", timeout=",
+              idleTimeout_.has_value()
+                  ? std::chrono::duration_cast<std::chrono::milliseconds>(
+                        idleTimeout_.value())
+                        .count()
+                  : -1,
+              "ms"));
       ex.setProxygenError(kErrorWriteTimeout);
       // This is a protocol error
       ex.setCodecStatusCode(ErrorCode::PROTOCOL_ERROR);
@@ -774,7 +801,16 @@ void HTTPTransaction::onIngressTimeout() {
     } else {
       HTTPException ex(
           HTTPException::Direction::INGRESS,
-          folly::to<std::string>("ingress timeout, streamID=", id_));
+          folly::to<std::string>(
+              "ingress timeout, streamID=",
+              id_,
+              ", timeout=",
+              idleTimeout_.has_value()
+                  ? std::chrono::duration_cast<std::chrono::milliseconds>(
+                        idleTimeout_.value())
+                        .count()
+                  : -1,
+              "ms"));
       ex.setProxygenError(kErrorTimeout);
       onError(ex);
     }
@@ -840,6 +876,21 @@ void HTTPTransaction::onEgressHeaderFirstByte() {
   if (transportCallback_) {
     transportCallback_->firstHeaderByteFlushed();
   }
+
+  if (txnObserverContainer_.hasObserversForEvent<
+          HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+    const auto e =
+        HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+            .setTimestamp(proxygen::SteadyClock::now())
+            .setType(HTTPTransactionObserverInterface::TxnBytesEvent::Type::
+                         FIRST_HEADER_BYTE_WRITE)
+            .build();
+    txnObserverContainer_.invokeInterfaceMethod<
+        HTTPTransactionObserverInterface::Events::TxnBytes>(
+        [&e](auto observer, auto observed) {
+          observer->onBytesEvent(observed, e);
+        });
+  }
 }
 
 void HTTPTransaction::onEgressBodyFirstByte() {
@@ -847,6 +898,20 @@ void HTTPTransaction::onEgressBodyFirstByte() {
   if (transportCallback_) {
     transportCallback_->firstByteFlushed();
   }
+
+  if (txnObserverContainer_.hasObserversForEvent<
+          HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+    const auto e = HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                       .setTimestamp(proxygen::SteadyClock::now())
+                       .setType(HTTPTransactionObserverInterface::
+                                    TxnBytesEvent::Type::FIRST_BODY_BYTE_WRITE)
+                       .build();
+    txnObserverContainer_.invokeInterfaceMethod<
+        HTTPTransactionObserverInterface::Events::TxnBytes>(
+        [&e](auto observer, auto observed) {
+          observer->onBytesEvent(observed, e);
+        });
+  }
 }
 
 void HTTPTransaction::onEgressBodyLastByte() {
@@ -854,6 +919,20 @@ void HTTPTransaction::onEgressBodyLastByte() {
   if (transportCallback_) {
     transportCallback_->lastByteFlushed();
   }
+
+  if (txnObserverContainer_.hasObserversForEvent<
+          HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+    const auto e = HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                       .setTimestamp(proxygen::SteadyClock::now())
+                       .setType(HTTPTransactionObserverInterface::
+                                    TxnBytesEvent::Type::LAST_BODY_BYTE_WRITE)
+                       .build();
+    txnObserverContainer_.invokeInterfaceMethod<
+        HTTPTransactionObserverInterface::Events::TxnBytes>(
+        [&e](auto observer, auto observed) {
+          observer->onBytesEvent(observed, e);
+        });
+  }
 }
 
 void HTTPTransaction::onEgressTrackedByte() {
@@ -868,6 +947,20 @@ void HTTPTransaction::onEgressLastByteAck(std::chrono::milliseconds latency) {
   if (transportCallback_) {
     transportCallback_->lastByteAcked(latency);
   }
+
+  if (txnObserverContainer_.hasObserversForEvent<
+          HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+    const auto e = HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                       .setTimestamp(proxygen::SteadyClock::now())
+                       .setType(HTTPTransactionObserverInterface::
+                                    TxnBytesEvent::Type::LAST_BODY_BYTE_ACK)
+                       .build();
+    txnObserverContainer_.invokeInterfaceMethod<
+        HTTPTransactionObserverInterface::Events::TxnBytes>(
+        [&e](auto observer, auto observed) {
+          observer->onBytesEvent(observed, e);
+        });
+  }
 }
 
 void HTTPTransaction::onLastEgressHeaderByteAcked() {
@@ -915,6 +1008,21 @@ void HTTPTransaction::onEgressTrackedByteEventAck(const ByteEvent& event) {
   if (transportCallback_) {
     transportCallback_->trackedByteEventAck(event);
   }
+
+  if (ByteEvent::FIRST_BYTE == event.eventType_ &&
+      txnObserverContainer_.hasObserversForEvent<
+          HTTPTransactionObserverInterface::Events::TxnBytes>()) {
+    const auto e = HTTPTransactionObserverInterface::TxnBytesEvent::Builder()
+                       .setTimestamp(proxygen::SteadyClock::now())
+                       .setType(HTTPTransactionObserverInterface::
+                                    TxnBytesEvent::Type::FIRST_BODY_BYTE_ACK)
+                       .build();
+    txnObserverContainer_.invokeInterfaceMethod<
+        HTTPTransactionObserverInterface::Events::TxnBytes>(
+        [&e](auto observer, auto observed) {
+          observer->onBytesEvent(observed, e);
+        });
+  }
 }
 
 void HTTPTransaction::onEgressTransportAppRateLimited() {
@@ -1129,8 +1237,8 @@ size_t HTTPTransaction::sendDeferredBody(uint32_t maxEgress) {
                                windowAvailable > 0 ? windowAvailable : 0)
           : maxEgress;
 
-  // We shouldn't be called if we have no pending body/EOM, egress is paused, or
-  // the send window is closed
+  // We shouldn't be called if we have no pending body/EOM, egress is paused,
+  // or the send window is closed
   const size_t bytesLeft = getOutstandingEgressBodyBytes();
   INVARIANT_RETURN((bytesLeft > 0 || isEgressEOMQueued()) && sendWindow > 0, 0);
 
@@ -1391,10 +1499,9 @@ void HTTPTransaction::sendEOM() {
               << "ingressState=" << ingressState_ << ", "
               << "egressPaused=" << egressPaused_ << ", "
               << "ingressPaused=" << ingressPaused_ << ", "
-              << "aborted=" << aborted_ << ", "
-              << "enqueued=" << isEnqueued() << ", "
-              << "chainLength=" << deferredEgressBody_.chainLength() << ", "
-              << "bufferMetaLen=" << deferredBufferMeta_.length << "]"
+              << "aborted=" << aborted_ << ", " << "enqueued=" << isEnqueued()
+              << ", " << "chainLength=" << deferredEgressBody_.chainLength()
+              << ", " << "bufferMetaLen=" << deferredBufferMeta_.length << "]"
               << " on " << *this;
     }
   } else {
@@ -1608,6 +1715,9 @@ void HTTPTransaction::resumeIngress() {
       case HTTPEvent::Type::UPGRADE:
         processIngressUpgrade(callback.getUpgradeProtocol());
         break;
+      case HTTPEvent::Type::ERROR:
+        processIngressError(*callback.getError());
+        break;
     }
   }
 }
@@ -1950,9 +2060,9 @@ HTTPTransaction::TxnStreamWriteHandle::writeStreamData(
   if (*fcState == Transport::FCState::UNBLOCKED) {
     return folly::makeSemiFuture(folly::unit);
   } else {
-    auto contract = folly::makePromiseContract<folly::Unit>();
-    writePromise_.emplace(std::move(contract.first));
-    return std::move(contract.second);
+    auto [promise, future] = folly::makePromiseContract<folly::Unit>();
+    writePromise_.emplace(std::move(promise));
+    return std::move(future);
   }
 }
 
@@ -2051,9 +2161,10 @@ HTTPTransaction::TxnStreamReadHandle::readStreamData() {
     txn_.wtIngressStreams_.erase(getID());
     return folly::makeSemiFuture<WebTransport::StreamData>(std::move(ex));
   } else if (buf_.empty() && !eof_) {
-    auto contract = folly::makePromiseContract<WebTransport::StreamData>();
-    readPromise_.emplace(std::move(contract.first));
-    return std::move(contract.second);
+    auto [promise, future] =
+        folly::makePromiseContract<WebTransport::StreamData>();
+    readPromise_.emplace(std::move(promise));
+    return std::move(future);
   } else {
     auto bufLen = buf_.chainLength();
     WebTransport::StreamData streamData({buf_.move(), eof_});
