@@ -34,6 +34,12 @@ class H3DatagramAsyncSocket
     SERVER = 1,
   };
 
+  struct H3Capsule {
+    uint64_t type{0};
+    uint64_t length{0};
+    std::unique_ptr<folly::IOBuf> data;
+  };
+
   struct Options {
     Mode mode_;
     std::chrono::milliseconds txnTimeout_{10000};
@@ -42,6 +48,7 @@ class H3DatagramAsyncSocket
     folly::Optional<std::pair<std::string, std::string>> certAndKey_;
     std::shared_ptr<const fizz::CertificateVerifier> certVerifier_;
     uint16_t maxDatagramSize_{1400};
+    std::function<void(H3Capsule&&)> capsuleCallback_;
   };
 
  public:
@@ -127,16 +134,12 @@ class H3DatagramAsyncSocket
     return -1;
   }
 
-  ssize_t recvmsg(struct msghdr* /*msg*/, int /*flags*/) override {
-    return -1;
-  }
+  ssize_t recvmsg(struct msghdr* /*msg*/, int /*flags*/) override;
 
-  int recvmmsg(struct mmsghdr* /*msgvec*/,
-               unsigned int /*vlen*/,
-               unsigned int /*flags*/,
-               struct timespec* /*timeout*/) override {
-    return -1;
-  }
+  int recvmmsg(struct mmsghdr* msgvec,
+               unsigned int vlen,
+               unsigned int flags,
+               struct timespec* /*timeout*/) override;
 
   void resumeRead(ReadCallback* cob) override;
 
@@ -154,16 +157,17 @@ class H3DatagramAsyncSocket
   }
 
   folly::NetworkSocket getNetworkSocket() const override {
-    LOG(FATAL) << __func__ << " not supported";
-    folly::assume_unreachable();
+    // Not great but better than crashing.
+    VLOG(4) << "getNetworkSocket returning fake socket";
+    return folly::NetworkSocket();
   }
 
   void setReusePort(bool /*reusePort*/) override {
-    LOG(FATAL) << __func__ << " not supported";
+    // Meaningless
   }
 
   void setReuseAddr(bool /*reuseAddr*/) override {
-    LOG(FATAL) << __func__ << " not supported";
+    // Meaningless
   }
 
   void setRcvBuf(int rcvBuf) override {
@@ -183,24 +187,20 @@ class H3DatagramAsyncSocket
   }
 
   void setBusyPoll(int /*busyPollUs*/) override {
-    LOG(FATAL) << __func__ << " unsupported";
-    folly::assume_unreachable();
+    VLOG(4) << "busy poll not supported";
   }
 
   void dontFragment(bool /*df*/) override {
-    LOG(FATAL) << __func__ << " unsupported";
-    folly::assume_unreachable();
+    // Meaningless.
   }
 
   void setDFAndTurnOffPMTU() override {
-    LOG(FATAL) << __func__ << " unsupported";
-    folly::assume_unreachable();
+    // Meaningless.
   }
 
-  void setErrMessageCallback(
-      ErrMessageCallback* /*errMessageCallback*/) override {
-    LOG(FATAL) << __func__ << " unsupported";
-    folly::assume_unreachable();
+  void setErrMessageCallback(ErrMessageCallback*) override {
+    // TODO do we want to support this and convey errors this way?
+    VLOG(4) << "err message callback not supported";
   }
 
   bool isBound() const override {
@@ -304,6 +304,7 @@ class H3DatagramAsyncSocket
   std::deque<std::unique_ptr<folly::IOBuf>> readBuf_;
   // Buffers Outgoing Datagrams before the transport is ready
   std::deque<std::unique_ptr<folly::IOBuf>> writeBuf_;
+  std::unique_ptr<folly::IOBuf> pendingDelivery_;
 
   bool transportConnected_ : 1;
   bool pendingEOM_ : 1;
