@@ -16,14 +16,13 @@
 
 #include <folly/portability/Time.h>
 
-#include <openssl/ossl_typ.h>
-
 namespace proxygen {
 
 using SteadyClock = std::chrono::steady_clock;
 using SystemClock = std::chrono::system_clock;
 using TimePoint = SteadyClock::time_point;
 using SystemTimePoint = SystemClock::time_point;
+using SteadyTimePoint = SteadyClock::time_point;
 
 template <typename T>
 bool durationInitialized(const T& duration) {
@@ -159,16 +158,6 @@ inline std::string getDateTimeStr(TimePoint tp) {
   return "";
 }
 
-/**
- * Helper method to convert to OpenSSL type ASN1_TIME to a printable date and
- * time string.
- *
- * @param time    a pointer to the ASN1_TIME instance to be converted.
- * @return        a human readable date and time string for the openssl type
- *                ASN1_TIME. If there is any error, returns empty string.
- */
-std::string getDateTimeStr(const ASN1_TIME* const time);
-
 /**
  * Class used to get steady time. We use a separate class to mock it easier.
  */
